# coding: utf-8
# Copyright (c) 2016, 2026, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125

from __future__ import absolute_import

from .analyze_document_details import AnalyzeDocumentDetails
from .analyze_document_result import AnalyzeDocumentResult
from .analyze_image_details import AnalyzeImageDetails
from .analyze_image_result import AnalyzeImageResult
from .analyze_video_result import AnalyzeVideoResult
from .analyze_video_stream_result import AnalyzeVideoStreamResult
from .bounding_polygon import BoundingPolygon
from .cell import Cell
from .change_model_compartment_details import ChangeModelCompartmentDetails
from .change_project_compartment_details import ChangeProjectCompartmentDetails
from .change_stream_group_compartment_details import ChangeStreamGroupCompartmentDetails
from .change_stream_job_compartment_details import ChangeStreamJobCompartmentDetails
from .change_stream_source_compartment_details import ChangeStreamSourceCompartmentDetails
from .change_vision_private_endpoint_compartment_details import ChangeVisionPrivateEndpointCompartmentDetails
from .create_document_job_details import CreateDocumentJobDetails
from .create_image_job_details import CreateImageJobDetails
from .create_model_details import CreateModelDetails
from .create_project_details import CreateProjectDetails
from .create_stream_group_details import CreateStreamGroupDetails
from .create_stream_job_details import CreateStreamJobDetails
from .create_stream_source_details import CreateStreamSourceDetails
from .create_video_job_details import CreateVideoJobDetails
from .create_vision_private_endpoint_details import CreateVisionPrivateEndpointDetails
from .data_science_labeling_dataset import DataScienceLabelingDataset
from .dataset import Dataset
from .detected_document_type import DetectedDocumentType
from .detected_language import DetectedLanguage
from .dimensions import Dimensions
from .document_classification_feature import DocumentClassificationFeature
from .document_details import DocumentDetails
from .document_feature import DocumentFeature
from .document_field import DocumentField
from .document_job import DocumentJob
from .document_key_value_detection_feature import DocumentKeyValueDetectionFeature
from .document_language_classification_feature import DocumentLanguageClassificationFeature
from .document_metadata import DocumentMetadata
from .document_table_detection_feature import DocumentTableDetectionFeature
from .document_text_detection_feature import DocumentTextDetectionFeature
from .face import Face
from .face_detection_feature import FaceDetectionFeature
from .face_embedding_feature import FaceEmbeddingFeature
from .field_label import FieldLabel
from .field_name import FieldName
from .field_value import FieldValue
from .image_classification_feature import ImageClassificationFeature
from .image_details import ImageDetails
from .image_feature import ImageFeature
from .image_job import ImageJob
from .image_object import ImageObject
from .image_object_detection_feature import ImageObjectDetectionFeature
from .image_text import ImageText
from .image_text_detection_feature import ImageTextDetectionFeature
from .inline_document_details import InlineDocumentDetails
from .inline_image_details import InlineImageDetails
from .input_location import InputLocation
from .label import Label
from .landmark import Landmark
from .line import Line
from .model import Model
from .model_collection import ModelCollection
from .model_summary import ModelSummary
from .model_version_details import ModelVersionDetails
from .normalized_vertex import NormalizedVertex
from .object_list_inline_input_location import ObjectListInlineInputLocation
from .object_location import ObjectLocation
from .object_properties import ObjectProperties
from .object_property import ObjectProperty
from .object_storage_dataset import ObjectStorageDataset
from .object_storage_document_details import ObjectStorageDocumentDetails
from .object_storage_image_details import ObjectStorageImageDetails
from .object_storage_output_location import ObjectStorageOutputLocation
from .ontology_class import OntologyClass
from .output_location import OutputLocation
from .page import Page
from .private_stream_network_access_details import PrivateStreamNetworkAccessDetails
from .processing_error import ProcessingError
from .project import Project
from .project_collection import ProjectCollection
from .project_summary import ProjectSummary
from .rtsp_source_details import RtspSourceDetails
from .stream_group import StreamGroup
from .stream_group_collection import StreamGroupCollection
from .stream_group_overlap import StreamGroupOverlap
from .stream_group_summary import StreamGroupSummary
from .stream_job import StreamJob
from .stream_job_collection import StreamJobCollection
from .stream_job_summary import StreamJobSummary
from .stream_network_access_details import StreamNetworkAccessDetails
from .stream_output_location import StreamOutputLocation
from .stream_source import StreamSource
from .stream_source_collection import StreamSourceCollection
from .stream_source_details import StreamSourceDetails
from .stream_source_summary import StreamSourceSummary
from .table import Table
from .table_row import TableRow
from .tracking_type import TrackingType
from .update_model_details import UpdateModelDetails
from .update_project_details import UpdateProjectDetails
from .update_stream_group_details import UpdateStreamGroupDetails
from .update_stream_job_details import UpdateStreamJobDetails
from .update_stream_source_details import UpdateStreamSourceDetails
from .update_vision_private_endpoint_details import UpdateVisionPrivateEndpointDetails
from .value_array import ValueArray
from .value_date import ValueDate
from .value_integer import ValueInteger
from .value_number import ValueNumber
from .value_phone_number import ValuePhoneNumber
from .value_string import ValueString
from .value_time import ValueTime
from .video_face import VideoFace
from .video_face_detection_feature import VideoFaceDetectionFeature
from .video_face_frame import VideoFaceFrame
from .video_face_segment import VideoFaceSegment
from .video_feature import VideoFeature
from .video_job import VideoJob
from .video_label import VideoLabel
from .video_label_detection_feature import VideoLabelDetectionFeature
from .video_label_segment import VideoLabelSegment
from .video_metadata import VideoMetadata
from .video_object import VideoObject
from .video_object_detection_feature import VideoObjectDetectionFeature
from .video_object_frame import VideoObjectFrame
from .video_object_segment import VideoObjectSegment
from .video_object_tracking_feature import VideoObjectTrackingFeature
from .video_segment import VideoSegment
from .video_stream_face_detection_feature import VideoStreamFaceDetectionFeature
from .video_stream_feature import VideoStreamFeature
from .video_stream_metadata import VideoStreamMetadata
from .video_stream_object import VideoStreamObject
from .video_stream_object_detection_feature import VideoStreamObjectDetectionFeature
from .video_stream_object_tracking_feature import VideoStreamObjectTrackingFeature
from .video_text import VideoText
from .video_text_detection_feature import VideoTextDetectionFeature
from .video_text_frame import VideoTextFrame
from .video_text_segment import VideoTextSegment
from .video_tracked_object import VideoTrackedObject
from .video_tracked_object_properties import VideoTrackedObjectProperties
from .video_tracked_object_segment import VideoTrackedObjectSegment
from .video_tracking_frame import VideoTrackingFrame
from .vision_private_endpoint import VisionPrivateEndpoint
from .vision_private_endpoint_collection import VisionPrivateEndpointCollection
from .vision_private_endpoint_summary import VisionPrivateEndpointSummary
from .word import Word
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .work_request_summary_collection import WorkRequestSummaryCollection

# Maps type names to classes for ai_vision services.
ai_vision_type_mapping = {
    "AnalyzeDocumentDetails": AnalyzeDocumentDetails,
    "AnalyzeDocumentResult": AnalyzeDocumentResult,
    "AnalyzeImageDetails": AnalyzeImageDetails,
    "AnalyzeImageResult": AnalyzeImageResult,
    "AnalyzeVideoResult": AnalyzeVideoResult,
    "AnalyzeVideoStreamResult": AnalyzeVideoStreamResult,
    "BoundingPolygon": BoundingPolygon,
    "Cell": Cell,
    "ChangeModelCompartmentDetails": ChangeModelCompartmentDetails,
    "ChangeProjectCompartmentDetails": ChangeProjectCompartmentDetails,
    "ChangeStreamGroupCompartmentDetails": ChangeStreamGroupCompartmentDetails,
    "ChangeStreamJobCompartmentDetails": ChangeStreamJobCompartmentDetails,
    "ChangeStreamSourceCompartmentDetails": ChangeStreamSourceCompartmentDetails,
    "ChangeVisionPrivateEndpointCompartmentDetails": ChangeVisionPrivateEndpointCompartmentDetails,
    "CreateDocumentJobDetails": CreateDocumentJobDetails,
    "CreateImageJobDetails": CreateImageJobDetails,
    "CreateModelDetails": CreateModelDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "CreateStreamGroupDetails": CreateStreamGroupDetails,
    "CreateStreamJobDetails": CreateStreamJobDetails,
    "CreateStreamSourceDetails": CreateStreamSourceDetails,
    "CreateVideoJobDetails": CreateVideoJobDetails,
    "CreateVisionPrivateEndpointDetails": CreateVisionPrivateEndpointDetails,
    "DataScienceLabelingDataset": DataScienceLabelingDataset,
    "Dataset": Dataset,
    "DetectedDocumentType": DetectedDocumentType,
    "DetectedLanguage": DetectedLanguage,
    "Dimensions": Dimensions,
    "DocumentClassificationFeature": DocumentClassificationFeature,
    "DocumentDetails": DocumentDetails,
    "DocumentFeature": DocumentFeature,
    "DocumentField": DocumentField,
    "DocumentJob": DocumentJob,
    "DocumentKeyValueDetectionFeature": DocumentKeyValueDetectionFeature,
    "DocumentLanguageClassificationFeature": DocumentLanguageClassificationFeature,
    "DocumentMetadata": DocumentMetadata,
    "DocumentTableDetectionFeature": DocumentTableDetectionFeature,
    "DocumentTextDetectionFeature": DocumentTextDetectionFeature,
    "Face": Face,
    "FaceDetectionFeature": FaceDetectionFeature,
    "FaceEmbeddingFeature": FaceEmbeddingFeature,
    "FieldLabel": FieldLabel,
    "FieldName": FieldName,
    "FieldValue": FieldValue,
    "ImageClassificationFeature": ImageClassificationFeature,
    "ImageDetails": ImageDetails,
    "ImageFeature": ImageFeature,
    "ImageJob": ImageJob,
    "ImageObject": ImageObject,
    "ImageObjectDetectionFeature": ImageObjectDetectionFeature,
    "ImageText": ImageText,
    "ImageTextDetectionFeature": ImageTextDetectionFeature,
    "InlineDocumentDetails": InlineDocumentDetails,
    "InlineImageDetails": InlineImageDetails,
    "InputLocation": InputLocation,
    "Label": Label,
    "Landmark": Landmark,
    "Line": Line,
    "Model": Model,
    "ModelCollection": ModelCollection,
    "ModelSummary": ModelSummary,
    "ModelVersionDetails": ModelVersionDetails,
    "NormalizedVertex": NormalizedVertex,
    "ObjectListInlineInputLocation": ObjectListInlineInputLocation,
    "ObjectLocation": ObjectLocation,
    "ObjectProperties": ObjectProperties,
    "ObjectProperty": ObjectProperty,
    "ObjectStorageDataset": ObjectStorageDataset,
    "ObjectStorageDocumentDetails": ObjectStorageDocumentDetails,
    "ObjectStorageImageDetails": ObjectStorageImageDetails,
    "ObjectStorageOutputLocation": ObjectStorageOutputLocation,
    "OntologyClass": OntologyClass,
    "OutputLocation": OutputLocation,
    "Page": Page,
    "PrivateStreamNetworkAccessDetails": PrivateStreamNetworkAccessDetails,
    "ProcessingError": ProcessingError,
    "Project": Project,
    "ProjectCollection": ProjectCollection,
    "ProjectSummary": ProjectSummary,
    "RtspSourceDetails": RtspSourceDetails,
    "StreamGroup": StreamGroup,
    "StreamGroupCollection": StreamGroupCollection,
    "StreamGroupOverlap": StreamGroupOverlap,
    "StreamGroupSummary": StreamGroupSummary,
    "StreamJob": StreamJob,
    "StreamJobCollection": StreamJobCollection,
    "StreamJobSummary": StreamJobSummary,
    "StreamNetworkAccessDetails": StreamNetworkAccessDetails,
    "StreamOutputLocation": StreamOutputLocation,
    "StreamSource": StreamSource,
    "StreamSourceCollection": StreamSourceCollection,
    "StreamSourceDetails": StreamSourceDetails,
    "StreamSourceSummary": StreamSourceSummary,
    "Table": Table,
    "TableRow": TableRow,
    "TrackingType": TrackingType,
    "UpdateModelDetails": UpdateModelDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "UpdateStreamGroupDetails": UpdateStreamGroupDetails,
    "UpdateStreamJobDetails": UpdateStreamJobDetails,
    "UpdateStreamSourceDetails": UpdateStreamSourceDetails,
    "UpdateVisionPrivateEndpointDetails": UpdateVisionPrivateEndpointDetails,
    "ValueArray": ValueArray,
    "ValueDate": ValueDate,
    "ValueInteger": ValueInteger,
    "ValueNumber": ValueNumber,
    "ValuePhoneNumber": ValuePhoneNumber,
    "ValueString": ValueString,
    "ValueTime": ValueTime,
    "VideoFace": VideoFace,
    "VideoFaceDetectionFeature": VideoFaceDetectionFeature,
    "VideoFaceFrame": VideoFaceFrame,
    "VideoFaceSegment": VideoFaceSegment,
    "VideoFeature": VideoFeature,
    "VideoJob": VideoJob,
    "VideoLabel": VideoLabel,
    "VideoLabelDetectionFeature": VideoLabelDetectionFeature,
    "VideoLabelSegment": VideoLabelSegment,
    "VideoMetadata": VideoMetadata,
    "VideoObject": VideoObject,
    "VideoObjectDetectionFeature": VideoObjectDetectionFeature,
    "VideoObjectFrame": VideoObjectFrame,
    "VideoObjectSegment": VideoObjectSegment,
    "VideoObjectTrackingFeature": VideoObjectTrackingFeature,
    "VideoSegment": VideoSegment,
    "VideoStreamFaceDetectionFeature": VideoStreamFaceDetectionFeature,
    "VideoStreamFeature": VideoStreamFeature,
    "VideoStreamMetadata": VideoStreamMetadata,
    "VideoStreamObject": VideoStreamObject,
    "VideoStreamObjectDetectionFeature": VideoStreamObjectDetectionFeature,
    "VideoStreamObjectTrackingFeature": VideoStreamObjectTrackingFeature,
    "VideoText": VideoText,
    "VideoTextDetectionFeature": VideoTextDetectionFeature,
    "VideoTextFrame": VideoTextFrame,
    "VideoTextSegment": VideoTextSegment,
    "VideoTrackedObject": VideoTrackedObject,
    "VideoTrackedObjectProperties": VideoTrackedObjectProperties,
    "VideoTrackedObjectSegment": VideoTrackedObjectSegment,
    "VideoTrackingFrame": VideoTrackingFrame,
    "VisionPrivateEndpoint": VisionPrivateEndpoint,
    "VisionPrivateEndpointCollection": VisionPrivateEndpointCollection,
    "VisionPrivateEndpointSummary": VisionPrivateEndpointSummary,
    "Word": Word,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "WorkRequestSummaryCollection": WorkRequestSummaryCollection
}
